@@ -6,6 +6,7 @@ import numpy as np
 class GJLine(GJModelObject):
     def __init__(self, data):
         super().__init__(data)
+        self.transform_coords()
 
     def to_primitives(self, shift):
         if self.empty:
@@ -17,9 +18,16 @@ class GJLine(GJModelObject):
         model.buffers.semantics.set(self.empty_semantics(nvert))
         return [model]
 
+    def transform_coords(self):
+        self.coordinates = self.to_3d(self.coordinates)
+
     def prep_coords(self):
         return np.repeat(self.coordinates, 2, axis=0)[1:-1]
 
+    @property
+    def flatten_vertices(self):
+        return np.array(self.coordinates).flatten()
+
 
 class GJMultiLine(GJLine):
     def __init__(self, data):
@@ -29,4 +37,17 @@ class GJMultiLine(GJLine):
         verts = []
         for linestring in self.coordinates:
             verts.append(np.repeat(linestring, 2, axis=0)[1:-1])
-        return np.concatenate(verts, dtype=np.float32)
\ No newline at end of file
+        return np.concatenate(verts, dtype=np.float32)
+
+    def transform_coords(self):
+        segments = []
+        for linestring in self.coordinates:
+            segments.append(self.to_3d(linestring))
+        self.coordinates = segments
+
+    @property
+    def flatten_vertices(self):
+        flat = []
+        for linestring in self.coordinates:
+            flat.extend(linestring)
+        return np.array(flat).flatten()
\ No newline at end of file
